<?php

namespace Drupal\commerce_colissimo_shipping\Plugin\Commerce\CheckoutPane;

use \Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneInterface;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use \Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use \SoapClient;
use Drupal\Core\Render\Element;

/**
 * @CommerceCheckoutPane(
 *  id = "commerce_checkout_pane",
 *  label = @Translation("Colissimo map"),
 *  display_label = @Translation("Colissimo map"),
 *  default_step = "string",
 *  wrapper_element = "string",
 * )
 */
class ColissimoMap extends CheckoutPaneBase implements  CheckoutPaneInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The parent checkout flow.
   *
   * @var \Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowWithPanesInterface
   */
  protected $checkoutFlow;

  /**
   * The current order.
   *
   * @var \Drupal\commerce_order\Entity\OrderInterface
   */
  protected $order;

  /**
   * Constructs a new CheckoutPaneBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface $checkout_flow
   *   The parent checkout flow.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CheckoutFlowInterface $checkout_flow, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $checkout_flow, $entity_type_manager);

    $this->checkoutFlow = $checkout_flow;
    $this->order = $checkout_flow->getOrder();
    $this->setConfiguration($configuration);
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, CheckoutFlowInterface $checkout_flow = NULL) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $checkout_flow,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $panel_form['container'] = [
      'msj' => '',
      'postal_code' => '71001',
      'city' => 'PARIS',
      'country' => 'FR',
    ];
    return $panel_form + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildPaneForm(array $pane_form, FormStateInterface $form_state, array &$complete_form) {
    $node = \Drupal::entityTypeManager()->getStorage('node')->load(2);

    // Obtain from shipping form.
    $URI = 'https://ws.colissimo.fr/pointretrait-ws-cxf/PointRetraitServiceWS/2.0?wsdl';
    $arguments = [
      'zipCode' => $this->configuration['container']['postal_code'],
      'city' => $this->configuration['container']['city'],
      'countryCode' => $this->configuration['container']['country'],
      'shippingDate' => date('d/m/Y'),
      'weight' => (float) 1000,
      'optionInter' => 0, // Permet de filtrer ou non les points situés à l’étranger
      // 'address' => ,
    ];

    $point_types = array();
    $shipping_service['name'] = 'socolissimo_post_office';

    switch ($shipping_service['name']) {
    case 'socolissimo_cityssimo':
      $point_types[] = 'CIT';
      break;

    case 'socolissimo_local_store':
      $point_types[] = 'A2P';
      $point_types[] = 'CMT';
      break;

    case 'socolissimo_post_office':
      $point_types[] = 'BPR';
      $point_types[] = 'ACP';
      $point_types[] = 'CDI';
      $point_types[] = 'BDP';
      break;
    }

    $geofield = $this->getApiColissimo('findRDVPointRetraitAcheminement',$arguments,$point_types,$URI);

    $pane_form['container'] = array(
      '#type' => 'details',
      '#title' => $this->t('Maps container'),
      '#attributes' => array(
        'class' => array(
          'map-container',
        ),
      ),
      '#open' => TRUE,
    );
    $pane_form['container']['msj'] = [
      '#markup' => $this->t('This is a custom completion message.'),
    ];
    $pane_form['container']['postal_code'] = [
      '#type' => 'textfield',
      '#title' => 'Postal Code',
      '#default_value' => $this->configuration['container']['postal_code'],
    ];
    $pane_form['container']['city'] = [
      '#type' => 'textfield',
      '#title' => 'City',
      '#default_value' => $this->configuration['container']['city'],
    ];
    $pane_form['container']['country'] = [
      '#type' => 'select',
      '#title' => 'City',
      '#empty_option' => '- Empty -',
      '#options' => [
        'FR' => 'France',
        'BE' => 'Belgique'
      ],
      '#default_value' => $this->configuration['container']['country'],
    ];

    $pane_form['container']['search'] = array(
      '#type' => 'button',
      '#value' => $this->t('Search'),
      /*
      '#ajax' => array(
        // 'callback' => $this->ajaxSubmit($pane_form, $form_state, $complete_form),
        'callback' => $this->submitPaneForm($pane_form, $form_state, $complete_form),
        'event' => 'keyup',
        'progress' => array(
          'type' => 'throbber',
          'message' => NULL,
        ),
      ),
      */
    );

    $pane_form['container']['maps'] = [
      '#theme' => 'colissimo_shipping_maps',
      // '#description' => $this->configuration['description'],
      '#description' => 'Maps description',
      '#attached' => array(
        'library' => array(
          'commerce_colissimo_shipping/colissimo_map',
        ),
        'drupalSettings' => array(
          // Return the first Geofield value
          'geofield' => $node->get('field_geofield')->getValue()[0],
          // 'geofield' => $geofield,
          'title' => $node->getTitle(),
          'offices' => $geofield,
        ),
      ),
    ];

    return $pane_form;

  }
  /**
   * {@inheritdoc}
   */
  public function validatePaneForm(array &$pane_form, FormStateInterface $form_state, array &$complete_form) {
    // Validates the pane form.
  }
  /**
   * {@inheritdoc}
   */
  public function submitPaneForm(array &$pane_form, FormStateInterface $form_state, array &$complete_form) {

    if (!$form_state->getErrors()) {
      $values = $form_state->getValue($pane_form['#parents']);
      $container = $values['container'];
      $this->configuration['container']['postal_code'] = $container['postal_code'];
      $this->configuration['container']['city'] = $container['city'];
      $this->configuration['container']['country'] = $container['country'];

      // drupal_set_message('Your company has been registered.', 'status');
      // $url = \Drupal\Core\Url::fromRoute('entity.node.canonical', ['node' => 2]);
      // return $form_state->setRedirectUrl($url);
    }
  }
  /**
   * {@inheritdoc}
   */
  public function ajaxSubmit(array &$pane_form, FormStateInterface $form_state, array &$complete_form) {
    // Handles the submission of an pane form.
    // drupal_set_message(t("I'm ajax"),'status');
  }
  /**
   * {@inheritdoc}
   */
  public function getApiColissimo($method, $arguments, $point_types, $URI, &$error = NULL) {
    // Handles the submission of an pane form.
    $arguments += array(
      'accountNumber' => '',
      'password' => '',
    );

    try {
      $arrContextOptions = array(
        'ssl' => array(
          'verify_peer' => false,
          'verify_peer_name' => false,
          'crypto_method' => STREAM_CRYPTO_METHOD_TLS_CLIENT
        ),
      );

      $options = array(
        'soap_version'=>SOAP_1_1,
        'exceptions'=>true,
        'trace'=>1,
        'cache_wsdl'=>WSDL_CACHE_NONE,
        'connection_timeout' => 30,
        'stream_context' => stream_context_create($arrContextOptions)
      );
      $client = new SoapClient($URI, $options);
      $result = $client->$method($arguments);

      // return $result;

      $offices = array();
      $offices[] = [
        'name' => 'PARIS ITALIE',
        'lat' => 48.8287,
        'lon' => 2.35678,
        'adress' => '23 AVENUE D ITALIE',
        'city' => 'PARIS',
        'country' => 'France',
        'codePostal' => 75013,
      ];
      $offices[] = [
        'name' => 'PARIS OLYMPIADES',
        'lat' => 48.824,
        'lon' => 2.36348,
        'adress' => '19 RUE SIMONE WEIL',
        'city' => 'PARIS',
        'country' => 'France',
        'codePostal' => 75013,
      ];
      return $offices;

    } catch (Exception $e) {
      return $e->getMessage();
    }

  }

}
